tic
%% m-file redwing %%

% program to simulate ingestion of insecticide in food items

%<-----------------Variables---------------------------->
% a is proportion of item in diet
% p is the proportion of contaminated food items consumed
% w is mean weight of food items consumed per day (g/day)
% wt is weight of consum species (g)
% v is insecticide concentration in food item (mg/kg)
	%~~ v1 seeds
	%~~ v2 insects
	%~~ v3 leaves  
% d is the dissipation rate
% e is excretion rate
% Q is the insecticide body burden (mg/kg)
% qmean is the average of Q
% pmean is the population average
% steq is the variance of Q
% step is the variance of population P
% LCLQ is the Lower Confidence Level of Q
% UCLQ is the Upper Confidence Level of Q
% LCLP is the Lower Confidence Level of P
% UCLP is the Upper Confidence Level of P
%<------------------------------------------------------>

clear all
clear nd;				%resets matrices
clear matr;
clear P;
clear difference;
clear A;
clear B;
close all

a1 = 0.3;
a2 = 0.5;
a3 = 1 - a1 - a2;
p = 1.0;
pf = 0.15;
pws = 1.0;
pwg = 0.19;
pis = pf*pws;
pig = pf*pwg;
v1mean = 13.5;
v2mean = 7.7;
v1sd = 4.23;
v2sd = 0.423;
wt = 58;
wg=0.064;               %weight of granule%
vg=0.15;                %granule pesticide concentration%
e = 0.5116/24;
k1 = 0.0689/24;
k2 = 0.0689/24;
k3 = 0.0689/24;
w = (0.398/24) * (wt^0.850);
p1 = 1;					%mortality probability
p2 = 65;        		%LD50
p3 = 15;                %LD50-LD10%
tmax = 120;             %#of days
sptime = 60;            %Spray day%
popnum=100; %number of individuals in the population
Q = zeros(1, (tmax*24)+1);
m = zeros(tmax*24,popnum);
pop = zeros(1, tmax*24);
I=zeros(tmax*24,popnum);           %intializes matrices to store out ingestion data
matr=zeros(tmax*24,popnum)-1;      %intializes matrices to store out body burden data
totgran=zeros(tmax,popnum);        %intializes matrices to store out granular ingestion data
daygran=zeros(tmax,popnum);  
mort=zeros(tmax*24,1);  %deaths at each hour
mtime=zeros(1,95);

for n = 1:popnum    %number of individuals
clear Q;
clear d1;
clear d2;
clear d3;
gran = 0;               %Initial number of granules consumed/hour%
i=0;            %counter
Q(1) = 0.00;            %Initial body burden%

pop(1)=popnum;             %Initial number of individuals%
for t = 1:tmax
   for hour = 1:24
      i=i+1;
      u=rand;
            if u<0.05;
                ng=2;         %number of granules ingested
            else
                ng=0;
            end;
      if ((4<=hour && hour<=9) || (15<=hour && hour<=18));
          
            dg=exp(-0.014146*i/24);
            G = pig*wg*vg*dg*1000*ng/wt;
            if t>=sptime
               v1 = v1mean + (v1sd * randn);
               v2 = v2mean + (v2sd * randn);
               %v3 = v3mean + (v3sd * randn);
          
                d1 = exp((-k1 * (i-sptime*24-1)));
                d2 = exp((-k2 * (i-sptime*24-1)));
                d3 = exp((-k3 * (i-sptime*24-1)));
                term1 = a1 * v1 * d1 + a2 * v2 * d2;
                I(i,n) = pis * w * term1./ wt;
            else
                I(i,n)=0;
            end        
      else
         I(i,n)=0;
         G=0;
      end;
      Q(i+1) = Q(i) + I(i) + G - e*Q(i);
    
      if Q(i)>0             %mortality probability based on body burden
            m(i,n) = p1./(1+exp((2.2/p3)*(p2-Q(i))));
        else
            m(i,n)=0;
      end;
        
      matr(i,n) = Q(i);
      gran(i+1) = gran(i) + ng;     
    
      dead=rand;
    if dead < m(i,n);
   		mort(i)=mort(i)+1;    %if random number is less than mortality probability, individual dies
        mtime(n)=i;     %saves out time of death for each individual
        break   %breaks out of hour loop
    end;
     
  end						%end of hourly loop%
  totgran(t,n) = max(gran);     %matrix of total granular consumption by individual
  daygran(t,n) = gran(hour);    %matrix of daily granular consumption by individual
  if dead<m(i,n)      %breaks out of day loop
        break
  end;
   
end						%end of daily loop%

   clear gran;
   
end						%end of individual for loop

%<------------------------------------------------------>
popl(1)=n;
for popl=1:tmax*24
    pop(popl+1)=pop(popl)-mort(popl);       %vector of population level
end;

%for j=1:(tmax*24)
 %   alive=find(matr(j,:)>-1);
%numalive(j)=length(alive);
%end;

mvect=popnum-pop;       %vector of mortality
clean=find(matr<0);
matr(clean)=0;
alive=pop(2:length(pop));
sum(mort)

qmean2=zeros(length(pop),1);        %initializes vectors for body burden in living stats to prevent dividing by zero
qstd2=zeros(length(pop),1);
steq2=zeros(length(pop),1);
LCLQ2=zeros(length(pop),1);
UCLQ2=zeros(length(pop),1);

cut=find(pop>0);
for j=1:((tmax*24)-1)        %stats for body burden in living population
qmean2(j) = sum(matr(j,:))/alive(j);
qstd2(j) = std(matr(j,:));
steq2(j) = qstd2(j) / sqrt(alive(j));
LCLQ2(j) = qmean2(j) - 1.96 *steq2(j);
UCLQ2(j) = qmean2(j) + 1.96 *steq2(j);
end;

figure            %body burden plot (population average of living)
  plot (qmean2, 'r');
  hold on
  plot (LCLQ2, 'b');
  plot (UCLQ2, 'g');
  hold off
  title ('Living average');
  xlabel ('Time (hours)');
  ylabel ('Body Burden');

figure     %population size plot
plot(pop);
  title ('Population Size');
  xlabel ('Time (hours)');
  ylabel ('# of individuals');
  
figure              %total mortality plot
plot(mvect);
title('Total Mortality');
  ylabel('Number of Deaths');
  xlabel('Time(hours)');
  
permort=100*mvect./popnum;
figure
plot(permort);          %Percentage of mortality for entire population
title('Percent Mortality');
  ylabel('Percentage of Population Dead');
  xlabel('Time(hours)');
  
toc