%function dolphin
%PBTK model of diving behavior
function Qdot = dolphin(t,Q)

AMTAL=0;

% Physiological Parameters

BW = 200.;		% Body weight (kg)
HR = 90.;       % Heart rate (beats/min)
SV = .0559;     % Stroke volume (L/beat)
Vt = 5.0;       % Tidal volume (L/breath)
f = 3.9;        % Breathing frequency  (breaths/min) Williams, et al. 1999
QV = Vt*f;      % Ventilation rate (L/min)
VARC = .025; 	% Fractional volume arterial blood 
VVC = .045; 	% Fractional volume venous blood 
VALC = .005; 	% Fractional volume alveolar space 
VLUC = .014; 	% Fractional volume lung tissue 
VLIC = .026; 	% Fractional volume liver tissue 
VFC = .213; 	% Fractional volume fat tissue 
VKC = .0044;	% Fractional volume kidney tissue 
VSC = .035;     % Fractional volume skin tissue
VOC = 1-(VARC+VVC+VALC+VLUC+VLIC+VFC+VKC+VSC);	% Fractional volume other tissue  
TCLU = 18; 		% Lung capillary volume (% of tissue volume)
TCLI = 13.8; 	% Liver capillary volume (% of tissue volume)
TCF = 2; 		% Fat capillary volume (% of tissue volume)
TCK = 16; 	    % Kidney capillary volume (% of tissue volume)
TCO = 4.5; 		% Other capillary volume (% of tissue volume)
TCS = 4.5;      % Skin capillary volume (% of tissue volume)
QLC = .23; 	    % Fractional blood flow to Liver (% of cardiac output)
QFC = .09; 		% Fractional blood flow to Fat (% of cardiac output)
QKC = .175;		% Fractional blood flow to Kidney (% of cardiac output)
QSC = .058;     % Fractional Blood Flow to Skin (% of cardiac ouput)
QOC = .447; 	% Fractional blood flow to Other (% of cardiac output)
PERM = .54; 	% Capillary Permeability Constant
PERMF =.23; 	% Fat Capillary Permeability Constant
%SA = 2000;         %Skin Area (cm^2)
%Kp = 10/60;		%Skin permeability constant (cm/min)
Dose = 1.2041e-3+0.3069e-3*randn;   %mg/L
Doseskin = 0.0;
if t < 10
   HR = 110;
   Dose = 1.2041e-3+0.3069e-3*randn;
   f = 3.9;
elseif (t > 10 && t < 15)
   HR = 30;
   Dose = 0;
   f = 0;
elseif (t >= 15 && t < 20)
   HR = 100;
   Dose = 1.2041e-3+0.3069e-3*randn;
   f = 10;
elseif t > 20;
    HR = 110;
    Dose = 1.2041e-3+0.3069e-3*randn;
    f = 3.9;
end;

% Metabolic Parameters
VMAXLI1 = 4.4544e-5/60; 	 	% Capacity of Saturable Metabolism in Liver (mg/L per minute)
KMLI1 = 1.536e-7;				% Affinity of Saturable Metabolism in Liver (mg/L)
VMAXLI2 = 1.0291e-5/60; 		% Capacity of Saturable Metabolism in Liver (mg/L per minute)
KMLI2 = 1.7536e-7;        		% Affinity of Saturable Metabolism in Liver (mg/L)
VMAXS1 = 4.4544e-5/60;  		% Capacity of Saturable Metabolism in Skin (mg/L per minute)
KMS1 = 1.536e-7; 		 		% Affinity of Saturable Metabolism in Skin (mg/L)
n = 2;                          % Hill constant
VMAXLU = 5.76e-6/60;			% Capacity of Saturable Metabolism in Lung (mg/L per minute)
KMLU = 1.536e-7;		 		% Affinity of Saturable Metabolism in Lung (mg/L)

% Chemical Parameters
PB = 235.5; 	% Blood/Air Partition Coefficient
PLI = 7.0; 		% Liver/Blood Partition Coefficient
PS = 10.0;      % Skin/Blood Partition Coefficient
PSA =6.0;       % Skin/Air Partition Coefficient
PLU = 1.81;		% Lung/Blood Partition Coefficient
PF = 160.4;		% Fat/Blood Partition Coefficient
PK = 4;			% Kidney/Blood Partition Coefficient 
PO = 4;			% Other/Blood Partition Coefficient

% Calculated Parameters
CO = HR*SV;             % Cardiac output (L/min)
QLI = QLC*CO;           % Liver Blood Flow (L/min)
QF = QFC*CO;            % Fat Blood Flow (L/min)
QK = QKC*CO;            % Kidney Blood Flow (L/min)
QO = QOC*CO;            % Other Blood Flow (L/min)
QS = QSC*CO;            % Skin Blood Flow (L/min)
QTO = QLI+QF+QK+QO+QS; 	% Total Blood Flow (L/min)
%QV = QPC*BW^0.74;		% Alveolar Ventilation (L/min)
VAR = VARC*BW; 	        % Arterial blood volume (L)
VV = VVC*BW; 	        % Venous blood (L)
VAL = VALC*BW; 	        % Alveolar space (L)
VLU = VLUC*BW; 	        % Lung tissue (L)
VLI = VLIC*BW; 	        % Liver tissue (L)
VF = VFC*BW; 	        % Fat tissue (L)
VK = VKC*BW;		    % Kidney tissue (L)
VS = VSC*BW;            % Skin Tissue (L)
VO = VOC*BW;	    	% Other tissue (L)
VCLU = ((TCLU/100)*VLU); % Lung capillary volume (L)
VCLI = ((TCLI/100)*VLI); % Liver capillary volume (L)
VCF = ((TCF/100)*VF);	% Fat capillary volume (L)
VCK = ((TCK/100)*VK); 	% Kidney capillary volume (L)
VCO = ((TCO/100)*VO); 	% Other tissue capillary volume (L)
VCS = ((TCS/100)*VS); 	% Skin tissue capillary volume (L)

%CO = HR*SV;
%Amount in Alveolar Space

AMTALdot = Dose*Vt*f+(Q(3)./VCLU)*(QV/PB)*PERM-(Q(1)./VAL)*QV*PERM-(Q(1)./VAL)*QV;

CA = AMTAL/VAL;
%if CA < 0
%   CA = 0;
%end;

CX = CA/PB;
%CXe = CX*1e6;

%Amount in Arterial Blood, Q(2)
AMTARdot = (Q(3)./VCLU)*QTO-(Q(2)./VAR)*QTO-QV*CX;

%Amount in Lung Capillary, Q(3)
AMTLUCdot = (Q(5)./VV)*QTO+(Q(1)./VAL)*QV*PERM+(Q(4)./VLU)*(QTO./PLU)*PERM-(Q(3)./VCLU)*QTO-(Q(3)./VCLU)*QTO*PERM-(Q(3)./VCLU)*(QV./PB)*PERM;

%Amount in Lung, Q(4)
AMTLUdot = (Q(3)./VCLU)*QTO*PERM-(Q(4)./VLU)*(QTO./PLU)*PERM-(VMAXLU*VLU*Q(4))./(KMLU*VLU+Q(4));

%Amount in Venous Blood, Q(5)
AMTVdot = ((Q(6)./VCLI)*QLI)+((Q(8)./VCK)*QK)+((Q(10)./VCF)*QF)+((Q(12)./VCO)*QO)+((Q(14)./VCS)*QS)-((Q(5)./VV)*QTO);

%Amount in Liver Capillary, Q(6)
AMTLICdot = (Q(2)./VAR)*QLI+(Q(7)./VLI)*(QLI./PLI)*PERM-(Q(6)./VCLI)*QLI-(Q(6)./VCLI)*QLI*PERM;

%Amount in Liver, Q(7)
AMTLIdot = (Q(6)./VCLI)*QLI*PERM-(Q(7)./VLI)*(QLI./PLI)*PERM-((VMAXLI1*VLI*Q(7))./(KMLI1*VLI+Q(7)))-((VMAXLI2*VLI*Q(7)^n)/(((KMLI2*VLI)^n)+Q(7)^n));

%Amount in kidney capillaries, Q(8)
AMTKCdot = (Q(2)./VAR)*QK+(Q(9)./VK)*(QK/PK)*PERM-(Q(8)./VCK)*QK-(Q(8)./VCK)*QK*PERM;

%Amount in kidney, Q(9)
AMTKdot = (Q(8)./VCK)*QK*PERM-(Q(9)./VK)*(QK./PK)*PERM;

%Amount in fat capillaries, Q(10)
AMTFCdot = (Q(2)./VAR)*QF+(Q(11)./VF)*(QF/PF)*PERMF-(Q(10)./VCF)*QF-(Q(10)./VCF)*QF*PERMF;

%Amount in fat, Q(11)
AMTFdot = (Q(10)./VCF)*QF*PERMF-(Q(11)./VF)*(QF./PF)*PERMF;

%Amount in other tissue capillaries, Q(12)
AMTOCdot = (Q(2)./VAR)*QO+(Q(13)./VO)*(QO/PO)*PERM-(Q(12)./VCO)*QO-(Q(12)./VCO)*QO*PERM;

%Amount in other tissues, Q(13)
AMTOdot = (Q(12)./VCO)*QO*PERM-(Q(13)./VO)*(QO./PO)*PERM;

%Amount in skin capillaries, Q(14)
AMTSCdot = (Q(2)./VAR)*QS+(Q(15)./VS)*(QS./PS)*PERM-(Q(14)./VCS)*QS-(Q(14)./VCS)*QS*PERM;

%Amount in skin, Q(15)
AMTSdot = (VS*(Doseskin-Q(15)/PSA))+(Q(14)./VCS)*QS*PERM-(Q(15)./VS)*(QS./PS)*PERM-((VMAXS1*VS*Q(15))./(KMS1*VS+Q(15)));
%AMTSdot = (Kp*SA*1e-3*(Doseskin-Q(15)/VS))+(Q(14)./VCS)*QS*PERM-(Q(15)./VS)*(QS./PS)*PERM-((VMAXS1*VS*Q(15))./(KMS1*VS+Q(15)));

Qdot = [AMTALdot;AMTARdot;AMTLUCdot;AMTLUdot;AMTVdot;AMTLICdot;...
        AMTLIdot;AMTKCdot;AMTKdot;AMTFCdot;AMTFdot;AMTOCdot;AMTOdot;AMTSCdot;AMTSdot];
