%m-file porpoise2n
%Naphthalene PBPK for Bottlenose Dolphin
%program to save normative output for sensitivity analysis
tic
clear all
close all

tmax = 180;
AMTAL=zeros(15,tmax);
AMTAR=zeros(15,tmax);
AMTLUC=zeros(15,tmax);
AMTLU=zeros(15,tmax);
AMTV=zeros(15,tmax);
AMTLIC=zeros(15,tmax);
AMTLI=zeros(15,tmax);
AMTKC=zeros(15,tmax);
AMTK=zeros(15,tmax);
AMTFC=zeros(15,tmax);
AMTF=zeros(15,tmax);
AMTOC=zeros(15,tmax);
AMTO=zeros(15,tmax);
AMTSC=zeros(15,tmax);
AMTS=zeros(15,tmax);

PB = 235.5;         % Blood/Air Partition Coefficient
BW = 200.;           % Body weight (kg)
VALC = .005; 		% Fraction alveolar space
VAL = VALC*BW;      % Alveolar space (L)

t = 1:1:tmax;
tspan = t;

for n = 1:5 %number of individuals

Q0 = [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0]';
[t,Q] = ode45(@porpoise,tspan,Q0);

AMTAL(n,:) = Q(:,1)';
AMTAR(n,:) = Q(:,2)';
AMTLUC(n,:) = Q(:,3)';
AMTLU(n,:) = Q(:,4)';
AMTV(n,:) = Q(:,5)';
AMTLIC(n,:) = Q(:,6)';
AMTLI(n,:) = Q(:,7)';
AMTKC(n,:) = Q(:,8)';
AMTK(n,:) = Q(:,9)';
AMTFC(n,:) = Q(:,10)';
AMTF(n,:) = Q(:,11)';
AMTOC(n,:) = Q(:,12)';
AMTO(n,:) = Q(:,13)';
AMTSC(n,:) = Q(:,14)';
AMTS(n,:) = Q(:,15)';
end;


CA = AMTAL/VAL;
   if CA < 0
      CA = 0;
   end;

CX = CA/PB;
CXe = CX*1e6;

MNAMTALn = mean(AMTAL);

MNAMTARn = mean(AMTAR);

MNAMTLUCn = mean(AMTLUC);

MNAMTLUn = mean(AMTLU);

MNAMTVn = mean(AMTV);

MNAMTLICn = mean(AMTLIC);

MNAMTLIn = mean(AMTLI);

MNAMTKCn = mean(AMTKC);

MNAMTKn = mean(AMTK);

MNAMTFCn = mean(AMTFC);

MNAMTFn = mean(AMTF);

MNAMTOCn = mean(AMTOC);

MNAMTOn = mean(AMTO);

MNAMTSCn = mean(AMTSC);

MNAMTSn = mean(AMTS);

MNCXen = mean(CXe);

% Save all variables from the workspace to testn.mat:
savefile = 'C:\MATLAB\testn.mat';
save (savefile, 'MNAMTALn', 'MNAMTARn','MNAMTLUn','MNAMTVn',...
     'MNAMTLIn','MNAMTKn','MNAMTFn','MNAMTOn','MNAMTSn','MNCXen');

if 1==0
figure
subplot(4,4,1);
hold on
plot (LCLAMTAL, 'k--','LineWidth',1);
plot (UCLAMTAL, 'k--','LineWidth',1);
plot (MNAMTAL, 'k-','LineWidth',1);
hold off
%xlabel('Time, min')
%ylabel('Amount of Naphthalene, mg','fontweight','d')
title ('Alveolar Space','fontweight','d')
subplot(4,4,2);
hold on
plot (LCLCXe, 'k--','LineWidth',1);
plot (UCLCXe, 'k--','LineWidth',1);
plot (MNCXe, 'k-','LineWidth',1);
%xlabel('Time, min')
hold off
title ('Exhaled','fontweight','d')
subplot(4,4,3);
hold on
plot (LCLAMTAR, 'k--','LineWidth',1);
plot (UCLAMTAR, 'k--','LineWidth',1);
plot (MNAMTAR, 'k-','LineWidth',1);
hold off
%xlabel('Time, min')
title ('Arterial Blood','fontweight','d')
subplot(4,4,4);
hold on
plot (LCLAMTLUC, 'k--','LineWidth',1);
plot (UCLAMTLUC, 'k--','LineWidth',1);
plot (MNAMTLUC, 'k-','LineWidth',1);
hold off
%xlabel('Time, min')
title ('Lung Capillary','fontweight','d')
subplot(4,4,5);
hold on
plot (LCLAMTLU, 'k--','LineWidth',1);
plot (UCLAMTLU, 'k--','LineWidth',1);
plot (MNAMTLU, 'k-','LineWidth',1);
hold off
%xlabel('Time, min','fontweight','d')
ylabel('Amount of Naphthalene, mg','fontweight','d')
title ('Lung','fontweight','d')
subplot(4,4,6);
hold on
plot (LCLAMTV, 'k--','LineWidth',1);
plot (UCLAMTV, 'k--','LineWidth',1);
plot (MNAMTV, 'k-','LineWidth',1);
hold off
%xlabel('Time, min','fontweight','d')
title ('Venous Blood','fontweight','d')
subplot(4,4,7);
hold on
plot (LCLAMTLIC, 'k--','LineWidth',1);
plot (UCLAMTLIC, 'k--','LineWidth',1);
plot (MNAMTLIC, 'k-','LineWidth',1);
hold off
%xlabel('Time, min','fontweight','d')
title ('Liver Capillary','fontweight','d')
subplot(4,4,8);
hold on
plot (LCLAMTLI, 'k--','LineWidth',1);
plot (UCLAMTLI, 'k--','LineWidth',1);
plot (MNAMTLI, 'k-','LineWidth',1);
hold off
%xlabel('Time, min','fontweight','d')
title ('Liver','fontweight','d')

%figure
subplot(4,4,9);
hold on
plot (LCLAMTKC, 'k--','LineWidth',1);
plot (UCLAMTKC, 'k--','LineWidth',1);
plot (MNAMTKC, 'k-','LineWidth',1);
hold off
%ylabel('Amount of Naphthalene, mg','fontweight','d')
title ('Kidney Capillary','fontweight','d')
subplot(4,4,10);
hold on
plot (LCLAMTK, 'k--','LineWidth',1);
plot (UCLAMTK, 'k--','LineWidth',1);
plot (MNAMTK, 'k-','LineWidth',1);
hold off
title ('Kidney','fontweight','d')
subplot(4,4,11);
hold on
plot (LCLAMTFC, 'k--','LineWidth',1);
plot (UCLAMTFC, 'k--','LineWidth',1);
plot (MNAMTFC, 'k-','LineWidth',1);
hold off
title ('Fat Capillary','fontweight','d')
subplot(4,4,12);
hold on
plot (LCLAMTF, 'k--','LineWidth',1);
plot (UCLAMTF, 'k--','LineWidth',1);
plot (MNAMTF, 'k-','LineWidth',1);
hold off
title ('Fat','fontweight','d')
subplot(4,4,13);
hold on
plot (LCLAMTOC, 'k--','LineWidth',1);
plot (UCLAMTOC, 'k--','LineWidth',1);
plot (MNAMTOC, 'k-','LineWidth',1);
hold off
xlabel('Time, min','fontweight','d')
%ylabel('Amount of Naphthalene, mg','fontweight','d')
title ('Other Capillary','fontweight','d')
subplot(4,4,14);
hold on
plot (LCLAMTO, 'k--','LineWidth',1);
plot (UCLAMTO, 'k--','LineWidth',1);
plot (MNAMTO, 'k-','LineWidth',1);
hold off
xlabel('Time, min','fontweight','d')
title ('Other','fontweight','d')
subplot(4,4,15);
hold on
plot (LCLAMTSC, 'k--','LineWidth',1);
plot (UCLAMTSC, 'k--','LineWidth',1);
plot (MNAMTSC, 'k-','LineWidth',1);
hold off
xlabel('Time, min','fontweight','d')
title ('Skin Capillary','fontweight','d')
subplot(4,4,16);
hold on
plot (LCLAMTS, 'k--','LineWidth',1);
plot (UCLAMTS, 'k--','LineWidth',1);
plot (MNAMTS, 'k-','LineWidth',1);
hold off
xlabel('Time, min','fontweight','d')
title ('Skin','fontweight','d')
end
toc