% m-file deathmarkov.m
% Markov chain model of death
% with and without toxicant exposure

clear all

N=14;
%initial state values.  All individuals start in S1
S1n=zeros(1,N+1);
S2n=zeros(1,N+1);
S3n=zeros(1,N+1);
S1y=zeros(1,N+1);
S2y=zeros(1,N+1);
S3y=zeros(1,N+1);
S1n(1)=100;S2n(1)=0;S3n(1)=0;      
S1y(1)=100;S2y(1)=0;S3y(1)=0;


for i=1:N
    % transition probabilities without exposure
    p11n=0.6;p12n=0.2;p13n=1-p11n-p12n;
    p21n=0.0;p22n=0.6;p23n=1-p21n-p22n;
    p31n=0.0;p32n=0.0;p33n=1.0;
    % transition probabilities with exposure
    p11y=0.2;p12y=0.4;p13y=1-p11y-p12y;
    p21y=0.0;p22y=0.4;p23y=1-p21y-p22y;
    p31y=0.0;p32y=0.0;p33y=1.0;
   
    % state equations
    S1n(i+1)=p11n*S1n(i)+p21n*S2n(i)+p31n*S3n(i);
    S2n(i+1)=p12n*S1n(i)+p22n*S2n(i)+p32n*S3n(i);
    S3n(i+1)=p13n*S1n(i)+p23n*S2n(i)+p33n*S3n(i);
    S1y(i+1)=p11y*S1y(i)+p21y*S2y(i)+p31y*S3y(i);
    S2y(i+1)=p12y*S1y(i)+p22y*S2y(i)+p32y*S3y(i);
    S3y(i+1)=p13y*S1y(i)+p23y*S2y(i)+p33y*S3y(i);
end
x=0:N;
%plot nonexposed
subplot(2,1,1)
plot(x,S1n,'b-',x,S2n,'r--',x,S3n,'g-.','LineWidth',2)
xlabel('Time')
ylabel('Number of Individuals')
title('Non-Exposed')
legend('Well','Ill', 'Dead')
grid on
%plot exposed
subplot(2,1,2)
plot(x,S1y,'b-',x,S2y,'r--',x,S3y,'g-.','LineWidth',2)
%hold all

grid on
xlabel('Time')
ylabel('Number of Individuals')
title('Exposed')
legend('Well','Ill', 'Dead')