% m-file eggresponse
% program to estimate a response surface model
% for striped bass egg mortality as a function
% of total residual chlorine (TRC), increase in
% temperature (deltaT), and exposure time (EXP)

% matrix of explanatory variables
[basseggdata,txt]=xlsread('stripedbasseggs2.xls','Sheet1','A2:C18');
X = [0.00 0.15 0.15 0.30 0.00 0.00 0.15 0.15 0.15 0.30 0.30 0.00 0.15 0.15 0.30 0.15 0.30;
     6 6 10 2 2 6 2 6 10 6 10 10 2 6 6 0 0;
     0.08 0.08 0.08 0.08 2.0 2.0 2.0 2.0 2.0 2.0 2.0 4.0 4.0 4.0 4.0 4.0 4.0]';
TRC = basseggdata(:,1);
deltaT = basseggdata(:,2);
Exp = basseggdata(:,3);
mort = [22.832 27.374 32.97 42.02 13.916 32.528...
      51.802 47.644 64.648 86.952 92.298 48.898...
      59.406 57.848 100.00 42.326 89.382]';

P2 = [17.526 13.681 15.895 19.441 19.749 15.792...
      20.580 17.327 18.727 17.258 16.796 17.640...
      18.942 17.970 17.311 19.589 18.803]';
  
P3 = [27.700 16.478 18.507 23.938 26.130 15.829...
      20.351 11.337  9.606 11.266 10.915 14.291...
       7.880  9.870 12.913 13.494 8.960]';
  
stats = regstats(mort,basseggdata,'quadratic','beta');
b = stats.beta; % Model coefficients
xx1 = linspace(min(TRC),max(TRC),25);
xx2 = linspace(min(deltaT),max(deltaT),25);
xx3 = linspace(min(Exp),max(Exp),25);

[X1,X2,X3] = meshgrid(xx1,xx2,xx3);

morthat = b(1) + b(2)*X1 + b(3)*X2 + b(4)*X3 + ...
       b(5)*X1.*X2 + b(6)*X1.*X3 + b(7)*X2.*X3 + ...
       b(8)*X1.^2 + b(9)*X2.^2 + b(10)*X3.^2;

hmodel = scatter3(X1(:),X2(:),X3(:),6,morthat(:),'filled');
hold on
hdata = scatter3(TRC,deltaT,Exp,'ko','filled');
axis tight
xn = {'TRC' 'deltaT' 'Exp'}
yn = {'mortality'}
xlabel('TRC')
ylabel('Delta T')
zlabel('Exposure Time')
hbar = colorbar;
ylabel(hbar,'Mortality');

% To plot a slice, uncomment the following three lines

%delete(hmodel)
%X2slice = 5; % Fix deltaT
%slice(X1,X2,X3,morthat,[],X2slice,[])

alpha = 0.01; % Significance level
rstool(X,mort,'quadratic',alpha,xn,yn)