% function thyroid
% model of hormone homeostasis
function Qdot = thyroid(t,Q)
%Constants for mass balance equations for TT3P and TT4P
a2 = 1.07; a3 = 0.292; a4 = 14.5; a7 = 0.0822;
a11 = 0.512; a12 = 0.501; a13 = 2.72; a15 = 0.1475;
% Normal value constants for fast and slow pools
TT3F = 10.65; TT3S = 2.34; TT4F = 231.0; TT4S = 223.0;
aHT = 4.1; TRH = 2.98;         %steady-state value of TRH
k1 = 0.269; k2 = 3.85; k3 = 131.0; k5 = 1.0;
kL = 0.77;          %loss rate of TSH in plasma
K = 0.8;
VP = 3.05;          %volumn of plasma
TSHnorm = 5.375;    %normal value of TSH
FT3Pnorm = 0.003*0.86;  %normal value of free plasma T3 concentration
FT3P = .003*Q(2);   %free plasma T3 concentration

if t>=10 && t<=20
   k1 = 0.0269;
   k2 = 0.385;
end

%Rate of change of TSH, Q(1)
TSHdot = aHT*log(TRH)-k3*FT3P-k5*(FT3P-FT3Pnorm)-kL*Q(1);
% SRT3 = rate of secretion of T3
SRT3 = k1*Q(1)+K*(Q(1) - TSHnorm);
% SRT4 = rate of secretion of T4
SRT4 = k2*Q(1)+K*(Q(1) - TSHnorm);
     
%Rate of chamge of plasma T3, Q(2)
TT3Pdot = (SRT3/VP) + a2*TT3F + a3*TT3S - a4*Q(2) - a7*Q(2);
%Rate of change of plasma T4, Q(3)
TT4Pdot = a11*TT4F + a12*TT4S + (SRT4/VP) - a13*Q(3) - a15*Q(3);
Qdot = [TSHdot; TT3Pdot; TT4Pdot];