% m-file wolfmoose
% Difference equation model of predator and prey
clear all
tic
K1 = 45.45;K2 = 1.6;
a = 7.760e-7;f = 2.7136e-8;
c = 0.75;g = 0.65;
b = 1.0;
d = 0.045;      %equilibrium predator death rate
%d = 0.0675;     %predator death rate x 1.5
xmax = 50;
Na = zeros(1,xmax,'double');
Pb = zeros(1,xmax,'double');
N = zeros(1,xmax+1,'double');
P = zeros(1,xmax+1,'double');
N(1) = 571.;P(1) = 28;
x = 1:1:xmax+1;
z = 1:1:xmax;
for t = 1:xmax
   Na(t) = P(t)*K1*(1-exp(-a*(N(t).^2)*(P(t).^(1-c))));
   Nar = floor(Na);
   Pb(t) = P(t)*K2*(1-exp(-f*(N(t).^2)*(P(t).^(1-g))));
   Pbr = floor(Pb);
   N(t+1) = N(t) + b*N(t) - Na(t);
   if N(t+1) < 0
      N(t+1) = 0;
   end
   Nr = floor(N);
   P(t+1) = P(t) + Pb(t) - d*P(t);
   Pr = floor(P);
end

hold on
subplot(2,2,1), plot(x,Nr,':o')
axis([0,xmax,500,900])
xlabel('Time (years)','fontsize',12)
ylabel('Number of Prey','fontsize',12)
subplot(2,2,2), plot(x,Pr,':o')
axis([0,xmax,24,30])
xlabel('Time (years)','fontsize',12)
ylabel('Number of Predators','fontsize',12)
subplot(2,2,3), plot(z,Nar,':o')
axis([0,xmax,500,900])
xlabel('Time (years)','fontsize',12)
ylabel('Number of Prey Attacked','fontsize',12)
subplot(2,2,4), plot(z,Pbr,':o')
axis([0,xmax,0.5,2.5])
xlabel('Time (years)','fontsize',12)
ylabel('Number of Predators Born','fontsize',12)
toc