%m-file daphnia_mercury2
%program to fit exponential model with nonlinear least squares
%regression using nlinfit

conc = [9699  4616  4170  2332  1567  1313  557  588
       11060  5281  5169  2868  1570   827  529  648
        9458  5624  5566  4199  2299  1014  531  436];

allconc = [9699  4616  4170  2332  1567  1313  557  588 ...
          11060  5281  5169  2868  1570   827  529  648 ...
           9458  5624  5566  4199  2299  1014  531  436];
allday = [0 1 2 3 7 9 11 14 ...
          0 1 2 3 7 9 11 14 ...
          0 1 2 3 7 9 11 14];
day = [0 1 2 3 7 9 11 14];

meanconc = mean(conc)
stdconc = std(conc)

beta0 = [8900; .3144; 400];
newx = 0:.1:15;

[beta,r,J,sigma] = nlinfit(allday,allconc,@daphnia_mercury,beta0)

betaci = nlparci(beta,r,'covar',sigma)

[yhat, delta] = nlpredci(@daphnia_mercury,newx,beta,r,'covar',sigma);

ucl = yhat + delta';
lcl = yhat - delta';

plot(allday, allconc,'ko')
xlabel('Day')
ylabel('Concentration, \mug\cdotkg^{-1}')

figure
errorbar(day,meanconc,stdconc,'k+')
hold on
plot(newx, yhat,'k-')
plot(newx, ucl, 'k--')
plot(newx, lcl, 'k--')
xlabel('Day')
ylabel('Hg Concentration, \mug\cdotkg^{-1}')