%m-file deer_weight3
%program to use nonlinear regression to fit a log model
%to deer weight as a function of age

%Independent variable
age = [0 0.5 1.5 2.5  3.5 4.5 7.5]';

%Dependent variable
male_weight = [0 78.2 126.0 150.0 214.5 236.0 237.0]';

plot(age,male_weight, 'ko')
xlabel('Age, years')
ylabel('Body Weight, lbs.')

%Initial parameter estimates
beta0 = [250; 1];
newx = 0:0.1:10;

%Generate parameter values, residuals, and Jacobian
[betahat,r,J,sigma] = nlinfit(age,male_weight,@deer_weight,beta0)
  
%Confidence intervals on parameters
betaci = nlparci(betahat,r,'covar',sigma)

%Confidence intervals on predicted values
%Delta is half widths of 95% CI

[yhat, delta] = nlpredci(@deer_weight,newx,betahat,r,'covar',sigma);
      
ucl = yhat + delta';
lcl = yhat - delta';
 
figure
plot(age, male_weight,'ko')
xlabel('Age, years')
ylabel('Body Weight, lbs.')
hold on
plot(newx, yhat,'r-')
plot(newx, ucl, 'b-')
plot(newx, lcl, 'g-')
hold off
 
Ymax = 250;
Y=male_weight;
logY = log(male_weight+1);
logYmax = log(Ymax);
term1 = (Ymax-Y)./Ymax;
term2 = log(term1);
 
figure
plot(age,term2,'o')
xlabel('Age')
ylabel('log((Ymax-Y)/Ymax)')
 
[b,bint,r,rint,stats] = regress(term2,age,.05)
 
yhat = b*newx;
figure
plot(age,term2,'ro')
hold on
%axis([0 250 0 250])
%axis square
plot(newx,yhat)
xlabel ('Age')
ylabel('log((Ymax-Y)/Ymax)')

linweight = Ymax*(1-exp(b*newx));
nlinweight = betahat(1)*(1-exp(-betahat(2)*newx));
figure
plot(newx,linweight,'r-')
hold on
plot(newx,nlinweight,'b--')
plot(age, male_weight,'ko')
xlabel('Age, years')
ylabel('Body Weight, lbs.')
legend('linear fit','nonlinear fit','Observed','Location','East')
